@@ -1,15 +1,14 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 from .parse import PTN
 
 __author__ = 'Giorgio Momigliano'
 __email__ = 'gmomigliano@protonmail.com'
-__version__ = '1.3.4'
+__version__ = '2.1'
 __license__ = 'MIT'
 
 ptn = PTN()
 
 
-def parse(name):
-    return ptn.parse(name)
+def parse(name, standardise=True):
+    return ptn.parse(name, standardise)
